@@ -17,8 +17,7 @@ GpsMaemo5::GpsMaemo5(QObject *parent) : QObject(parent) {
     urlloc = QUrl::fromEncoded("http://www.google.com/loc/json");
     worker = new QNetworkAccessManager();
     connect(worker, SIGNAL(finished(QNetworkReply *)), this, SLOT(finishedreply(QNetworkReply *)));
-
-    worker->post(QNetworkRequest(urlloc), QByteArray("{version:\"1.1.0\"}"));
+    gloc();
 #endif // Q_WS_MAEMO_5
 }
 
@@ -35,6 +34,12 @@ void GpsMaemo5_changed(LocationGPSDevice *device, GpsMaemo5 *gps) {
     }
 }
 #else
+void GpsMaemo5::gloc() {
+    qDebug() << "GpsMaemo5 gloc";
+    worker->post(QNetworkRequest(urlloc), QByteArray("{version:\"1.1.0\"}"));
+    QTimer::singleShot(60*1000, this, SLOT(gloc()));
+}
+
 void GpsMaemo5::finishedreply(QNetworkReply *r) {
     if ( r->url() == urlloc ) {
         QString loc = r->readAll();
