@@ -10,6 +10,7 @@ extern "C" {
 }
 #else
 #include <QtNetwork>
+#include <QTimer>
 #endif // Q_WS_MAEMO_5
 
 class GpsMaemo5 : public QObject {
@@ -31,6 +32,7 @@ public:
 #else
 private slots:
     void finishedreply(QNetworkReply *r);
+    void gloc();
 #endif // Q_WS_MAEMO_5
 
 private:
