@@ -26,6 +26,7 @@ private slots:
     void maps_login();
     void mode_buzz();
     void mode_latitude();
+    void mode_demonio();
 
 private:
     GoogleLatitude *glatitude;
@@ -33,6 +34,7 @@ private:
     QSettings *setting;
     QWebView *maps;
     QUrl url;
+    QAction *demonio;
 };
 
 #endif // LATITUDE_H
